@@ -14,7 +14,7 @@ LANGUAGES: Dict[str, str] = {
 
 MESSAGES: Dict[str, Dict[str, str]] = {
     "en": {
-        "welcome": "Welcome to Glitter — LAN file transfer.",
+        "welcome": "Welcome to Glitter — file transfer.",
         "icon": """
              @@@@@@@@@@@@@@             
          @@@@@@@@@@@@@@@@@@@@@@         
@@ -42,6 +42,34 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "select_language": "Select interface language:",
         "prompt_language_choice": "Enter language code [{default}]: ",
         "prompt_device_name": "Enter device name [{default}]: ",
+        "cli_description": "Glitter file transfer CLI",
+        "cli_usage": "%(prog)s [command]",
+        "cli_usage_prefix": "usage:",
+        "cli_error": "Error: {error}",
+        "cli_commands_title": "commands",
+        "cli_positionals_title": "positional arguments",
+        "cli_optionals_title": "optional arguments",
+        "cli_version_help": "show Glitter version and exit",
+        "cli_version_output": "Glitter version {version}",
+        "cli_help_help": "show this help message and exit",
+        "cli_send_help": "Send a file to the specified IP[:port]",
+        "cli_send_target_help": "Target peer ID or IP[:port] / [IPv6]:port",
+        "cli_send_path_help": "Path to the file or directory to send",
+        "cli_send_usage": "%(prog)s <target> <path>",
+        "cli_peers_help": "List discovered peers on the local network",
+        "cli_history_help": "Show recent transfer history",
+        "cli_history_clear_help": "Clear all transfer history records",
+        "cli_settings_help": "Open the interactive settings menu",
+        "cli_settings_language_help": "Set interface language immediately (available: {codes})",
+        "cli_settings_device_help": "Set device name immediately (no prompt)",
+        "cli_settings_clear_trust_help": "Clear trusted fingerprints without confirmation",
+        "cli_update_help": "Check for Glitter updates",
+        "cli_receive_help": "Receive files in auto-accept mode without the menu",
+        "cli_receive_mode_help": "Override auto-accept mode for this session (trusted|all)",
+        "cli_receive_dir_help": "Temporary download directory for this session",
+        "cli_receive_port_help": "Temporary transfer port for this session",
+        "cli_receive_no_encryption_help": "Temporarily disable encryption for this receive session",
+        "cli_path_warning": "Tip: The `glitter` command is not on PATH.",
         "menu_header": "Available actions:",
         "menu_options": "[1] List peers  [2] Send file  [3] Incoming requests  [4] Check updates  [5] History  [6] Settings  [7] Quit",
         "menu_pending": " ({count} pending)",
@@ -61,6 +89,7 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "send_cancelled": "Transfer cancelled.",
         "send_failed": "Transfer failed: {error}",
         "send_fingerprint_mismatch": "Transfer aborted: receiver fingerprint changed (expected {expected}, got {actual}). Remove the trusted entry if you trust the new device.",
+        "peers_waiting": "Scanning for peers... please wait up to {seconds:.0f}s.",
         "pending_header": "Pending incoming transfers:",
         "no_pending": "No pending transfer requests.",
         "pending_entry": "{index}. {filename} ({size} bytes) from {name} ({ip})",
@@ -98,8 +127,23 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "history_entry_send": "[SEND] {time} → {name} ({ip}) — {filename} ({size})",
         "history_entry_receive": "[RECV] {time} ← {name} ({ip}) — {filename} ({size}) saved to {path}",
         "history_entry_failed": "[{direction}] {time} with {name} ({ip}) — {filename} failed: {status}",
-        "settings_header": "Settings — language: {language_name} ({language_code}), device: {device}, port: {port}, encryption: {encryption}",
-        "settings_options": "[1] Change language  [2] Change device name  [3] Change transfer port  [4] Clear history  [5] Transfer encryption  [6] Clear trusted fingerprints  [7] Back",
+        "settings_header": "Settings — language: {language_name} ({language_code}), device: {device}, port: {port}, encryption: {encryption}, auto-accept: {auto_accept}",
+        "settings_options": "[1] Change language  [2] Change device name  [3] Change transfer port  [4] Change download directory  [5] Clear history  [6] Transfer encryption  [7] Auto-accept incoming transfers  [8] Clear trusted fingerprints  [9] Back",
+        "settings_download_dir_prompt": "Enter default receive directory (current: {current}) — press Enter to restore default:",
+        "settings_download_dir_updated": "Default receive directory updated: {path}",
+        "settings_download_dir_reset": "Default receive directory reset to: {path}",
+        "settings_download_dir_invalid": "Please enter an absolute path (e.g. /home/user/Downloads).",
+        "settings_download_dir_failed": "Failed to prepare directory: {error}",
+        "settings_language_invalid": "Invalid language code '{value}'. Available: {codes}.",
+        "settings_device_invalid": "Device name cannot be empty.",
+        "settings_auto_accept_on": "enabled",
+        "settings_auto_accept_off": "disabled",
+        "settings_auto_accept_state_off": "Off",
+        "settings_auto_accept_state_trusted": "Trusted peers only",
+        "settings_auto_accept_state_all": "All incoming transfers",
+        "settings_auto_accept_prompt": "Choose auto-accept mode (0=Off, 1=Trusted only, 2=All) [current: {state}]: ",
+        "settings_auto_accept_updated": "Auto-accept mode updated to {state}.",
+        "settings_auto_accept_all_warning": "Warning: All incoming transfers will be accepted automatically. Ensure you trust your network before using this mode.",
         "settings_prompt": "Choose a settings option: ",
         "settings_language_updated": "Language updated to {language_name}.",
         "settings_device_updated": "Device name updated to {name}.",
@@ -116,9 +160,21 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "settings_encryption_updated": "Transfer encryption is now {state}.",
         "settings_trust_clear_confirm": "Clear all trusted fingerprints? [y/N]: ",
         "settings_trust_cleared": "Trusted fingerprints cleared.",
+        "auto_accept_trusted_notice": "Auto-accepted trusted transfer '{filename}' from {name}. Saving to {path}.",
+        "auto_accept_trusted_busy": "Skipped auto-accept for '{filename}' because another transfer is in progress.",
+        "auto_accept_trusted_failed": "Auto-accept failed: {error}",
+        "auto_accept_all_notice": "Auto-accepted incoming transfer '{filename}' from {name}. Saving to {path}. (Sender not verified.)",
+        "auto_accept_trusted_rejected": "Declined untrusted transfer '{filename}' from {name} ({ip}) while running in 'trusted' receive mode.",
+        "receive_mode_invalid": "Invalid auto-accept mode '{value}'. Use off, trusted, or all.",
+        "receive_mode_off_disabled": "Auto-accept mode is Off. Enable trusted/all mode with running 'glitter receive'.",
+        "receive_dir_set": "Temporary download directory: {path}",
+        "receive_dir_error": "Failed to prepare directory: {error}",
+        "receive_waiting": "Listening for incoming transfers ({mode}). Press Ctrl+C to stop.",
+        "receive_encryption_disabled": "Warning: encryption disabled for this receive session only.",
+        "receive_shutdown": "Stopping receive service...",
     },
     "zh": {
-        "welcome": "欢迎使用 Glitter 局域网文件传输。",
+        "welcome": "欢迎使用 Glitter 文件传输。",
         "icon": """
              @@@@@@@@@@@@@@             
          @@@@@@@@@@@@@@@@@@@@@@         
@@ -146,6 +202,34 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "select_language": "请选择界面语言：",
         "prompt_language_choice": "输入语言代码 [{default}]：",
         "prompt_device_name": "请输入设备名称 [{default}]：",
+        "cli_description": "Glitter 文件传输 CLI",
+        "cli_usage": "%(prog)s [命令]",
+        "cli_usage_prefix": "用法:",
+        "cli_error": "错误: {error}",
+        "cli_commands_title": "命令",
+        "cli_positionals_title": "位置参数",
+        "cli_optionals_title": "可选参数",
+        "cli_version_help": "显示 Glitter 版本并退出",
+        "cli_version_output": "Glitter 版本 {version}",
+        "cli_help_help": "显示此帮助信息并退出",
+        "cli_send_help": "发送文件到指定 IP[:端口]",
+        "cli_send_target_help": "目标 Peer ID 或 IP（支持 IPv4/IPv6，可选端口，如 192.168.1.5:45846 或 [fe80::1]:45846）",
+        "cli_send_path_help": "要发送的文件或目录路径",
+        "cli_send_usage": "%(prog)s <target> <path>",
+        "cli_peers_help": "列出当前发现的局域网客户端",
+        "cli_history_help": "展示最近的传输记录",
+        "cli_history_clear_help": "一键清空全部传输记录",
+        "cli_settings_help": "打开交互式设置菜单",
+        "cli_settings_language_help": "直接切换界面语言（可选值：{codes}）",
+        "cli_settings_device_help": "直接设置设备名称（无需交互）",
+        "cli_settings_clear_trust_help": "直接清空信任指纹（无需确认）",
+        "cli_update_help": "检查 Glitter 更新",
+        "cli_receive_help": "以自动接收模式运行并接收文件",
+        "cli_receive_mode_help": "本次会话覆盖自动接收模式（trusted/all）",
+        "cli_receive_dir_help": "本次会话使用的临时保存目录",
+        "cli_receive_port_help": "本次会话使用的临时传输端口",
+        "cli_receive_no_encryption_help": "仅针对本次会话临时关闭加密",
+        "cli_path_warning": "提示：系统环境变量 PATH 中未找到 `glitter` 命令！",
         "menu_header": "可用操作：",
         "menu_options": "[1] 查看在线客户端  [2] 发送文件  [3] 待处理请求  [4] 查看更新  [5] 传输记录  [6] 设置  [7] 退出",
         "menu_pending": "（{count} 个待处理）",
@@ -165,6 +249,7 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "send_cancelled": "已取消本次传输。",
         "send_failed": "传输失败：{error}",
         "send_fingerprint_mismatch": "已终止：对方指纹变更（原 {expected}，现 {actual}）。如确认无误，请清除信任指纹后重试。",
+        "peers_waiting": "正在搜寻客户端，预计耗时 {seconds:.0f} 秒...",
         "pending_header": "待处理的接收请求：",
         "no_pending": "暂无待处理请求。",
         "pending_entry": "{index}. {filename}（{size} 字节），来自 {name}（{ip}）",
@@ -202,8 +287,23 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "history_entry_send": "【发送】{time} → {name}（{ip}）— {filename}（{size}）",
         "history_entry_receive": "【接收】{time} ← {name}（{ip}）— {filename}（{size}），保存到 {path}",
         "history_entry_failed": "【{direction}】{time} 与 {name}（{ip}）— {filename} 失败：{status}",
-        "settings_header": "设置 — 当前语言：{language_name} ({language_code})，设备名称：{device}，传输端口：{port}，传输加密：{encryption}",
-        "settings_options": "[1] 更改语言  [2] 更改设备名称  [3] 更改传输端口  [4] 清空传输记录  [5] 传输加密  [6] 清空信任指纹  [7] 返回",
+        "settings_header": "设置 — 当前语言：{language_name} ({language_code})，设备名称：{device}，传输端口：{port}，传输加密：{encryption}，自动接收：{auto_accept}",
+        "settings_options": "[1] 更改语言  [2] 更改设备名称  [3] 更改传输端口  [4] 更改默认接收目录  [5] 清空传输记录  [6] 传输加密  [7] 自动接收传入文件  [8] 清空信任指纹  [9] 返回",
+        "settings_download_dir_prompt": "请输入默认接收目录（当前：{current}），直接回车恢复默认：",
+        "settings_download_dir_updated": "默认接收目录已更新：{path}",
+        "settings_download_dir_reset": "默认接收目录已恢复为：{path}",
+        "settings_download_dir_invalid": "请输入绝对路径，例如 /home/user/Downloads。",
+        "settings_download_dir_failed": "创建目录失败：{error}",
+        "settings_language_invalid": "语言代码“{value}”无效，可选值：{codes}。",
+        "settings_device_invalid": "设备名称不能为空。",
+        "settings_auto_accept_on": "开启",
+        "settings_auto_accept_off": "关闭",
+        "settings_auto_accept_state_off": "关闭",
+        "settings_auto_accept_state_trusted": "仅限已信任设备",
+        "settings_auto_accept_state_all": "全部传入请求",
+        "settings_auto_accept_prompt": "请选择自动接收模式（0=关闭，1=仅已信任，2=全部）当前状态：{state}：",
+        "settings_auto_accept_updated": "自动接收模式已切换为：{state}。",
+        "settings_auto_accept_all_warning": "提示：将自动接收所有传入文件，请确保所处网络可靠后再开启此模式。",
         "settings_prompt": "请选择设置操作：",
         "settings_trust_clear_confirm": "确定要清空全部已信任指纹？[y/N]：",
         "settings_trust_cleared": "已清空已信任指纹。",
@@ -220,6 +320,18 @@ MESSAGES: Dict[str, Dict[str, str]] = {
         "settings_encryption_off": "已关闭",
         "settings_encryption_prompt": "是否开启传输加密？(y/n) 当前：{state}：",
         "settings_encryption_updated": "传输加密已切换为 {state}。",
+        "auto_accept_trusted_notice": "已自动接收来自可信 {name} 的文件“{filename}”，保存位置：{path}。",
+        "auto_accept_trusted_busy": "因正在进行其他传输，未自动接收“{filename}”。",
+        "auto_accept_trusted_failed": "自动接收失败：{error}",
+        "auto_accept_all_notice": "已自动接收来自 {name} 的文件“{filename}”，保存位置：{path}。（发送方身份未验证，请谨慎。）",
+        "auto_accept_trusted_rejected": "当前为“仅限已信任”模式，已拒绝来自 {name}（{ip}）的传输“{filename}”。",
+        "receive_mode_invalid": "自动接收模式“{value}”无效，请输入 off/trusted/all。",
+        "receive_mode_off_disabled": "当前自动接收模式为“关闭”。仅允许“仅限已信任”或“全部”使用 `glitter receive`。",
+        "receive_dir_set": "临时保存目录：{path}",
+        "receive_dir_error": "无法准备保存目录：{error}",
+        "receive_waiting": "正在监听传入文件（模式：{mode}），按 Ctrl+C 结束。",
+        "receive_encryption_disabled": "警告：本次接收会话已关闭加密（仅临时生效）。",
+        "receive_shutdown": "正在停止接收服务……",
     },
 }
 
@@ -236,6 +348,7 @@ def get_message(key: str, language: str, **kwargs: object) -> str:
 
 
 TONE_STYLES: Dict[str, str] = {
+    "icon": "#F4D03F",
     "banner": "bold cyan",
     "heading": "bold bright_cyan",
     "info": "bright_black",
@@ -248,7 +361,8 @@ TONE_STYLES: Dict[str, str] = {
 
 MESSAGE_TONES: Dict[str, str] = {
     "welcome": "",
-    "icon": "",
+    "cli_path_warning": "warning",
+    "icon": "icon",
     "select_language": "",
     "menu_header": "",
     "menu_options": "",
